api.system.components.code.v1.test_helpers.artifact package — Argus-Toolbelt 1.0 documentation

# api.system.components.code.v1.test_helpers.artifact package

## Submodules

## api.system.components.code.v1.test_helpers.artifact.create module

`api.system.components.code.v1.test_helpers.artifact.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.create_from_octet_stream module

`api.system.components.code.v1.test_helpers.artifact.create_from_octet_stream.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.create_from_octet_stream.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.create_from_octet_stream.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.create_from_octet_stream.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.delete_unused module

`api.system.components.code.v1.test_helpers.artifact.delete_unused.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.delete_unused.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.delete_unused.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.delete_unused.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.download_by_g_a_v module

`api.system.components.code.v1.test_helpers.artifact.download_by_g_a_v.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+/download, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.download_by_g_a_v.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+/download, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.download_by_g_a_v.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+/download, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.download_by_g_a_v.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+/download, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.download_by_id module

`api.system.components.code.v1.test_helpers.artifact.download_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/download, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.download_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/download, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.download_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/download, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.download_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/download, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.get_by_g_a_v module

`api.system.components.code.v1.test_helpers.artifact.get_by_g_a_v.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.get_by_g_a_v.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.get_by_g_a_v.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.get_by_g_a_v.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+/w+/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.get_by_id module

`api.system.components.code.v1.test_helpers.artifact.get_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.get_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.get_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.get_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/w+, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.list module

`api.system.components.code.v1.test_helpers.artifact.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.list_unused module

`api.system.components.code.v1.test_helpers.artifact.list_unused.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.list_unused.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.list_unused.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.list_unused.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/unused, respond with HTTP 401

## api.system.components.code.v1.test_helpers.artifact.search module

`api.system.components.code.v1.test_helpers.artifact.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/search, respond with HTTP 403

`api.system.components.code.v1.test_helpers.artifact.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/search, respond with HTTP 404

`api.system.components.code.v1.test_helpers.artifact.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/search, respond with HTTP 200

`api.system.components.code.v1.test_helpers.artifact.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/artifact/search, respond with HTTP 401

## Module contents